# sparql-language-server

A blazingly fast [language server](https://microsoft.github.io/language-server-protocol/specifications/lsp/3.17/specification) for [SPARQL](https://de.wikipedia.org/wiki/SPARQL), written in Rust :crab:.

# Demo

Check out the [Demo](https://sparql.nezis.de).

# capabilities

- Formatting
- Completions (Work in progess)
- Diagnostics (Work in progess)
